==> dojo-1.10.6.tgz: package/cldr/nls/sr/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E, h:mm a",
	"days-standAlone-short": [
		"не",
		"по",
		"ут",
		"ср",
		"че",
		"пе",
		"су"
	],
	"months-format-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-second-relative+0": "сада",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-weekday": "дан у недељи",
	"dateFormatItem-yQQQ": "QQQ. y",
	"dateFormatItem-yMEd": "E, d.M.y.",
	"field-wed-relative+0": "ове среде",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-wed-relative+1": "следеће среде",
	"eraNarrow": [
		"п.н.е.",
		"н.е."
	],
	"dateFormatItem-yMM": "MM.y.",
	"field-tue-relative+-1": "прошлог уторка",
	"dateFormatItem-MMMdd": "dd.MMM",
	"days-format-short": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormat-long": "dd. MMMM y.",
	"field-fri-relative+-1": "прошлог петка",
	"field-wed-relative+-1": "прошле среде",
	"months-format-wide": [
		"јануар",
		"фебруар",
		"март",
		"април",
		"мај",
		"јун",
		"јул",
		"август",
		"септембар",
		"октобар",
		"новембар",
		"децембар"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "поподне",
	"dateFormat-full": "EEEE, dd. MMMM y.",
	"field-thu-relative+-1": "прошлог четвртка",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-yMd": "d.M.y.",
	"dateFormatItem-yM": "M.y.",
	"field-era": "ера",
	"months-standAlone-wide": [
		"јануар",
		"фебруар",
		"март",
		"април",
		"мај",
		"јун",
		"јул",
		"август",
		"септембар",
		"октобар",
		"новембар",
		"децембар"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"Прво тромесечје",
		"Друго тромесечје",
		"Треће тромесечје",
		"Четврто тромесечје"
	],
	"timeFormat-long": "HH.mm.ss z",
	"dateFormatItem-yMMM": "MMM y.",
	"dateFormatItem-yQQQQ": "QQQQ. y",
	"field-year": "година",
	"dateFormatItem-MMdd": "MM-dd",
	"field-hour": "час",
	"months-format-abbr": [
		"јан",
		"феб",
		"мар",
		"апр",
		"мај",
		"јун",
		"јул",
		"авг",
		"сеп",
		"окт",
		"нов",
		"дец"
	],
	"field-sat-relative+0": "ове суботе",
	"field-sat-relative+1": "следеће суботе",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"field-thu-relative+0": "овог четвртка",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "прекосутра",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"јан",
		"феб",
		"мар",
		"апр",
		"мај",
		"јун",
		"јул",
		"авг",
		"сеп",
		"окт",
		"нов",
		"дец"
	],
	"quarters-format-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"quarters-standAlone-wide": [
		"Прво тромесечје",
		"Друго тромесечје",
		"Треће тромесечје",
		"Четврто тромесечје"
	],
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"dateFormatItem-MMMMd": "d. MMMM",
	"timeFormat-medium": "HH.mm.ss",
	"dateFormatItem-yMMdd": "dd.MM.y.",
	"field-sun-relative+0": "ове недеље",
	"dateFormatItem-Hm": "HH.mm",
	"quarters-standAlone-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"field-sun-relative+1": "следеће недеље",
	"eraAbbr": [
		"п. н. е.",
		"н. е."
	],
	"field-minute": "минут",
	"field-dayperiod": "пре подне/поподне",
	"days-standAlone-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-day-relative+-1": "јуче",
	"dateFormatItem-h": "hh a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "прекјуче",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, M-d",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "овог петка",
	"dateFormatItem-yMMMM": "MMMM y.",
	"field-fri-relative+1": "следећег петка",
	"field-day": "дан",
	"days-format-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"field-zone": "зона",
	"dateFormatItem-y": "y.",
	"months-standAlone-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-year-relative+-1": "Прошле године",
	"field-month-relative+-1": "Прошлог месеца",
	"dateFormatItem-hm": "hh.mm a",
	"days-format-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"eraNames": [
		"Пре нове ере",
		"Нове ере"
	],
	"dateFormatItem-yMMMd": "d. MMM y.",
	"days-format-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"days-standAlone-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "месец",
	"field-tue-relative+0": "овог уторка",
	"field-tue-relative+1": "следећег уторка",
	"dayPeriods-format-wide-am": "пре подне",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"dateFormatItem-EHm": "E, HH:mm",
	"field-mon-relative+0": "овог понедељка",
	"field-mon-relative+1": "следећег понедељка",
	"dateFormat-short": "d.M.yy.",
	"dateFormatItem-EHms": "E, HH:mm:ss",
	"dateFormatItem-Ehms": "E, h:mm:ss a",
	"field-second": "секунд",
	"field-sat-relative+-1": "прошле суботе",
	"dateFormatItem-yMMMEd": "E, d. MMM y.",
	"field-sun-relative+-1": "прошле недеље",
	"field-month-relative+0": "Овог месеца",
	"field-month-relative+1": "Следећег месеца",
	"dateFormatItem-Ed": "E d.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "недеља",
	"dateFormat-medium": "dd.MM.y.",
	"field-year-relative+0": "Ове године",
	"field-week-relative+-1": "Прошле недеље",
	"field-year-relative+1": "Следеће године",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "hh.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-mon-relative+-1": "прошлог понедељка",
	"field-week-relative+0": "Ове недеље",
	"field-week-relative+1": "Следеће недеље"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/sr/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E, h:mm a",
	"days-standAlone-short": [
		"не",
		"по",
		"ут",
		"ср",
		"че",
		"пе",
		"су"
	],
	"months-format-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-second-relative+0": "сада",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-weekday": "дан у недељи",
	"dateFormatItem-yQQQ": "QQQ. y",
	"dateFormatItem-yMEd": "E, d.M.y.",
	"field-wed-relative+0": "у среду",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-wed-relative+1": "следеће среде",
	"eraNarrow": [
		"п.н.е.",
		"н.е."
	],
	"dateFormatItem-yMM": "MM.y.",
	"field-tue-relative+-1": "прошлог уторка",
	"dateFormatItem-MMMdd": "dd.MMM",
	"days-format-short": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormat-long": "dd. MMMM y.",
	"field-fri-relative+-1": "прошлог петка",
	"field-wed-relative+-1": "прошле среде",
	"months-format-wide": [
		"јануар",
		"фебруар",
		"март",
		"април",
		"мај",
		"јун",
		"јул",
		"август",
		"септембар",
		"октобар",
		"новембар",
		"децембар"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "по подне",
	"dateFormat-full": "EEEE, dd. MMMM y.",
	"field-thu-relative+-1": "прошлог четвртка",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-yMd": "d.M.y.",
	"dateFormatItem-yM": "M.y.",
	"field-era": "ера",
	"months-standAlone-wide": [
		"јануар",
		"фебруар",
		"март",
		"април",
		"мај",
		"јун",
		"јул",
		"август",
		"септембар",
		"октобар",
		"новембар",
		"децембар"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"Прво тромесечје",
		"Друго тромесечје",
		"Треће тромесечје",
		"Четврто тромесечје"
	],
	"timeFormat-long": "HH.mm.ss z",
	"dateFormatItem-yMMM": "MMM y.",
	"dateFormatItem-yQQQQ": "QQQQ. y",
	"field-year": "година",
	"dateFormatItem-MMdd": "MM-dd",
	"field-hour": "сат",
	"months-format-abbr": [
		"јан",
		"феб",
		"мар",
		"апр",
		"мај",
		"јун",
		"јул",
		"авг",
		"сеп",
		"окт",
		"нов",
		"дец"
	],
	"field-sat-relative+0": "у суботу",
	"field-sat-relative+1": "следеће суботе",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"field-thu-relative+0": "у четвртак",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "прекосутра",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"јан",
		"феб",
		"мар",
		"апр",
		"мај",
		"јун",
		"јул",
		"авг",
		"сеп",
		"окт",
		"нов",
		"дец"
	],
	"quarters-format-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"quarters-standAlone-wide": [
		"Прво тромесечје",
		"Друго тромесечје",
		"Треће тромесечје",
		"Четврто тромесечје"
	],
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"dateFormatItem-MMMMd": "d. MMMM",
	"timeFormat-medium": "HH.mm.ss",
	"dateFormatItem-yMMdd": "dd.MM.y.",
	"field-sun-relative+0": "у недељу",
	"dateFormatItem-Hm": "HH.mm",
	"quarters-standAlone-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"field-sun-relative+1": "следеће недеље",
	"eraAbbr": [
		"п. н. е.",
		"н. е."
	],
	"field-minute": "минут",
	"field-dayperiod": "пре подне/по подне",
	"days-standAlone-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-day-relative+-1": "јуче",
	"dateFormatItem-h": "hh a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "прекјуче",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, M-d",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "у петак",
	"dateFormatItem-yMMMM": "MMMM y.",
	"field-fri-relative+1": "следећег петка",
	"field-day": "дан",
	"days-format-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"field-zone": "временска зона",
	"dateFormatItem-y": "y.",
	"months-standAlone-narrow": [
		"ј",
		"ф",
		"м",
		"а",
		"м",
		"ј",
		"ј",
		"а",
		"с",
		"о",
		"н",
		"д"
	],
	"field-year-relative+-1": "прошле године",
	"field-month-relative+-1": "прошлог месеца",
	"dateFormatItem-hm": "hh.mm a",
	"days-format-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"eraNames": [
		"Пре нове ере",
		"п. н. е.",
		"Нове ере",
		"н. е."
	],
	"dateFormatItem-yMMMd": "d. MMM y.",
	"days-format-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"days-standAlone-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "месец",
	"field-tue-relative+0": "у уторак",
	"field-tue-relative+1": "следећег уторка",
	"dayPeriods-format-wide-am": "пре подне",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"dateFormatItem-EHm": "E, HH:mm",
	"field-mon-relative+0": "у понедељак",
	"field-mon-relative+1": "следећег понедељка",
	"dateFormat-short": "d.M.yy.",
	"dateFormatItem-EHms": "E, HH:mm:ss",
	"dateFormatItem-Ehms": "E, h:mm:ss a",
	"field-second": "секунд",
	"field-sat-relative+-1": "прошле суботе",
	"dateFormatItem-yMMMEd": "E, d. MMM y.",
	"field-sun-relative+-1": "прошле недеље",
	"field-month-relative+0": "овог месеца",
	"field-month-relative+1": "следећег месеца",
	"dateFormatItem-Ed": "E d.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "недеља",
	"dateFormat-medium": "dd.MM.y.",
	"field-year-relative+0": "ове године",
	"field-week-relative+-1": "прошле недеље",
	"field-year-relative+1": "следеће године",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "hh.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-mon-relative+-1": "прошлог понедељка",
	"field-week-relative+0": "ове недеље",
	"field-week-relative+1": "следеће недеље"
}
//end v1.x content
);
